Collected Works Of James Joyce (General Fiction) - Artemis Book Sales

PDF Catalog

# Collected Works Of James Joyce

Category

General Fiction

ISBN

9781684126590

Dimensions

1.4 x 5.25 x 7.75 inches (Length x Width x Height)

Brand

Author

James Joyce

Imprint

Word Cloud Classics

Format

sb

Pack quantity

12

Your cost

$5.99
Available Quantity: 1000
Quantity

Description

Unflinching, fictional accounts of life in Ireland during the early twentieth century. This collection by James Joyce includes two of his most famous works: Portrait of the Artist as a Young Man and Dubliners. Joyce spent years writing an autobiographical novel that he later turned into his first novel, A Portrait of the Artist as a Young Man. It was first published as a book in 1916, shortly after its success as a magazine serial. Dubliners is a collection of fifteen short stories relating the often-gritty reality of Dublin’s middle class in the early twentieth century. With famous titles such as “The Dead” and “Eveline,” this collection is a must-read for enthusiasts of classic literature. The heat-burnished cover and small trim size make this Word Cloud Classic an excellent format to carry James Joyce with you anywhere you go.

#####

Modal content

#####

Modal content

##### Modal title

Modal body text goes here.